@@ -1,22 +1,29 @@
 <?php
 	# Mantis - a php based bugtracking system
 	# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
+	# Copyright (C) 2002 - 2004  Mantis Team   - mantisbt-dev@lists.sourceforge.net
 	# This program is distributed under the terms and conditions of the GPL
 	# See the README and LICENSE files for details
 
 	# Initial code for this addon cames from Duncan Lisset
 	# Modified and "make mantis codeguidlines compatible" by Rufinus
+
+	# --------------------------------------------------------
+	# $Id: summary_jpgraph_page.php,v 1.21 2004/03/05 01:26:16 jlatour Exp $
+	# --------------------------------------------------------
 ?>
-<?php include( "core_API.php" ) ?>
-<?php login_cookie_check() ?>
+<?php require_once( 'core.php' ) ?>
 <?php
-	db_connect( $g_hostname, $g_db_username, $g_db_password, $g_database_name );
+	access_ensure_project_level( config_get( 'view_summary_threshold' ) );
+
+	$t_project_id = helper_get_current_project();
+
+	$t_bug_table = config_get( 'mantis_bug_table' );
 
 	$t_res_val = RESOLVED;
-	$query = "SELECT id, UNIX_TIMESTAMP(date_submitted) as date_submitted,
-			UNIX_TIMESTAMP(last_updated) as last_updated
-			FROM $g_mantis_bug_table
-			WHERE project_id='$g_project_cookie_val' AND status='$t_res_val'";
+	$query = "SELECT id, date_submitted, last_updated
+			FROM $t_bug_table
+			WHERE project_id='$t_project_id' AND status='$t_res_val'";
 	$result = db_query( $query );
 	$bug_count = db_num_rows( $result );
 
@@ -25,8 +32,8 @@
 	$t_total_time = 0;
 	for ($i=0;$i<$bug_count;$i++) {
 		$row = db_fetch_array( $result );
-		$t_date_submitted = ($row["date_submitted"]);
-		$t_last_updated = $row["last_updated"];
+		$t_date_submitted = db_unixtimestamp( $row['date_submitted'] );
+		$t_last_updated = db_unixtimestamp( $row['last_updated'] );
 
 		if ($t_last_updated < $t_date_submitted) {
 			$t_last_updated = 0;
@@ -37,7 +44,7 @@
 		$t_total_time = $t_total_time + $t_diff;
 		if ( $t_diff > $t_largest_diff ) {
 			$t_largest_diff = $t_diff;
-			$t_bug_id = $row["id"];
+			$t_bug_id = $row['id'];
 		}
 	}
 	if ( $bug_count < 1 ) {
@@ -51,50 +58,50 @@
 
 
 ?>
-<?php print_page_top1() ?>
-<?php print_page_top2() ?>
+<?php html_page_top1() ?>
+<?php html_page_top2() ?>
 
-<?php print_summary_menu( $g_summary_jpgraph_page ) ?>
+<?php print_summary_menu( 'summary_jpgraph_page.php' ) ?>
 
-<p>
+<br />
 <table class="width100" cellspacing="1">
 <tr>
 	<td class="form-title" colspan="2">
-		<?php echo $s_summary_title ?>
+		<?php echo lang_get( 'summary_title' ) ?>
 	</td>
 </tr>
 <tr valign="top">
 	<td width="50%">
-		<img src="<?php echo $g_summary_jpgraph_cumulative_bydate ?>" border="0">
+		<img src="summary_graph_cumulative_bydate.php" border="0" />
 	</td>
 	<td width="50%">
-		<img src="<?php echo $g_summary_jpgraph_bydeveloper ?>" border="0">
+		<img src="summary_graph_bydeveloper.php" border="0" />
 	</td>
 </tr>
 <tr valign="top">
 	<td width="50%">
-		<img src="<?php echo $g_summary_jpgraph_byreporter ?>" border="0">
+		<img src="summary_graph_byreporter.php" border="0" />
 	</td>
 	<td width="50%">
-		<img src="<?php echo $g_summary_jpgraph_byseverity ?>" border="0">
+		<img src="summary_graph_byseverity.php" border="0" />
 	</td>
 </tr>
 <tr valign="top">
 	<td width="50%">
-		<img src="<?php echo $g_summary_jpgraph_bystatus ?>" border="0">
+		<img src="summary_graph_bystatus.php" border="0" />
 	</td>
 	<td width="50%">
-		<img src="<?php echo $g_summary_jpgraph_byresolution ?>" border="0">
+		<img src="summary_graph_byresolution.php" border="0" />
 	</td>
 </tr>
 <tr valign="top">
 	<td width="50%">
-		<img src="<?php echo $g_summary_jpgraph_bycategory ?>" border="0">
+		<img src="summary_graph_bycategory.php" border="0" />
 	</td>
 	<td width="50%">
-		<img src="<?php echo $g_summary_jpgraph_bypriority ?>" border="0">
+		<img src="summary_graph_bypriority.php" border="0" />
 	</td>
 </tr>
 </table>
 
-<?php print_page_bot1( __FILE__ ) ?>
\ No newline at end of file
+<?php html_page_bottom1( __FILE__ ) ?>
